@@ -17,5 +17,5 @@ class Database_Handler:
         return self.handler.search_for_records()
     
     def insert_record(self, keywords):
-        return self.handler.insert_row(keywords)
+        return self.handler.insert_row(**keywords)
     
\ No newline at end of file
